Description Public fields Methods Examples
semVer is an R6 class to create an object for working with Semantic versioning
semVer is an R6 class to create an object for working with Semantic versioning
SemVerVersionversion of semantic versioning rules to be followed currently only version 2.0.0 is supported.
higherThanAll()higherThanAll() test if the vector of versions passed in are
all lower than this object
semVer$higherThanAll(Versions)
Versionscharacter vector of semantically formatted version numbers
atomic boolean
sem <- semVer$new("3.0.0")
sem$higherThanAll(c("2.0.2", "0.1.0"))
new()initializes a new semVer object with the version supplied
semVer$new(Version = "", SemVerVersion = "2.0.0")
Versioncharacter of semantically formatted version numbers
SemVerVersiondefaults to "2.0.0" no other options currently available.
semVer object holding version data
sem <- semVer$new("3.0.0")
clone()The objects of this class are cloneable with this method.
semVer$clone(deep = FALSE)
deepWhether to make a deep clone.
1 2 3 4 5 6 7 8 9 10 11 12 | ## ------------------------------------------------
## Method `semVer$higherThanAll`
## ------------------------------------------------
sem <- semVer$new("3.0.0")
sem$higherThanAll(c("2.0.2", "0.1.0"))
## ------------------------------------------------
## Method `semVer$new`
## ------------------------------------------------
sem <- semVer$new("3.0.0")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.